## Sensu-Plugins-Matrix

## Functionality

This plugin provides a handler to send notifications to a Matrix chat.

## Files
 * bin/handler-matrix.rb

 ## Usage

After installation, you have to set up a `pipe` type handler, like so:

```json
{
  "handlers": {
    "matrix": {
      "type": "pipe",
      "command": "/opt/sensu/embedded/bin/handler-matrix.rb",
      "filter": "occurrences"
    }
  }
}
```

This gem also expects a JSON configuration file with the following contents:

```json
{
    "matrix": {
        "matrix_user": "sensu",
        "matrix_access_token": "MDYOURTOKEN_HERE",                                                                                                                                                                                      
        "matrix_server": "matrix.example.com",
        "matrix_room_id": "!TBDXXXXXXXXX:matrix.example.com"
    }
}   
```

### Parameters:
- `matrix_server`: The URL of the Matrix (synapse) instance
- `matrix_user`: The username of the Matrix account that will be used to send
  the messages. You probably want to use a special "bot" account for this.
- `password`: The password of the Matrix account that will be used to send
  the messages.
- `matrix_access_token`: You can also specify a access token instead of the password
- `matrix_room_id`: The room to which the error message is to be sent.
- `message_template` (optional): An ERB template in Markdown to use to format
  messages instead of the default. Supports the following variables:
  - `action_to_string`
  - `action_symbol`
  - `client_name`
  - `check_name`
  - `status_to_string`
  - `status_symbol`
  - `occurrences`
  - `output`
- `message_template_file` (optional): A file to read an ERB template in Markdown
  from to format messages. Supports the same variables as `message_template`.


### Advanced configuration

By default, the handler assumes that the config parameters are specified in the
`matrix` top-level key of the JSON, as shown above. You also have the option
to make the handler fetch the config from a different key. To do this, pass the
`-j` option to the handler with the name of the desired key You can define
multiple handlers, and each handler can send notifications to a different room
and from a different bot. You could, for example, have critical and non-critical
Matrix rooms, and send the notifications to one or the other depending on the
check. For example:

```json
{
  "handlers": {
    "critical_matrix": {
      "type": "pipe",
      "command": "/opt/sensu/embedded/bin/handler-matrix.rb -j critical_matrix_options"
    },
    "non_critical_matrix": {
      "type": "pipe",
      "command": "/opt/sensu/embedded/bin/handler-matrix.rb -j non_critical_matrix_options"
    }
  }
}
```